snp_calculateProjections.RdCalculate the axon lengths in annotated brain regions
snp_calculateProjections(
PathOfNeuron,
FlagFlip = FALSE,
Annotation,
StructureIDOfTargets,
Resolution,
NumOfCores,
OptionMetric = "LengthOfAxon"
)Full path of SWC file for each neuron
Whether flip neurons to the other hemisphere, e.g., neurons in right hemisphere were flipped to the left hemisphere.
3D array with each element assigned a positive value
Structure ID of brain regions or domains in the annotation. Column name of returned matrix is the same as StructureIDOfTargets.
Voxel size of each annotation, e.g., 100, 50, 25, 10 um
Number of cores for parallel computation
Default value is "LengthOfAxon". ("LengthOfAxon", "NumberOfEndNodes", "NumberOfBranchNodes")
projection matrix
Annotated brain regions can be any 3D array with an unique index denoting a brain region or domain